EXPORTS
	NewConsole @ 1 NONAME ; NewConsole
	_Z5Panic13TConsolePanic @ 2 NONAME ; Panic(TConsolePanic)
	_ZN8RConsole10ReadCancelEv @ 3 NONAME ; RConsole::ReadCancel()
	_ZN8RConsole11ClearScreenEv @ 4 NONAME ; RConsole::ClearScreen()
	_ZN8RConsole11SetUIColorsEjjj @ 5 NONAME ; RConsole::SetUIColors(unsigned int, unsigned int, unsigned int)
	_ZN8RConsole13SetTextColorsEjj @ 6 NONAME ; RConsole::SetTextColors(unsigned int, unsigned int)
	_ZN8RConsole15GetPaletteEntryEjRhS0_S0_ @ 7 NONAME ; RConsole::GetPaletteEntry(unsigned int, unsigned char&, unsigned char&, unsigned char&)
	_ZN8RConsole15SetCursorHeightEi @ 8 NONAME ; RConsole::SetCursorHeight(int)
	_ZN8RConsole15SetCursorPosAbsERK6TPoint @ 9 NONAME ; RConsole::SetCursorPosAbs(TPoint const&)
	_ZN8RConsole15SetCursorPosRelERK6TPoint @ 10 NONAME ; RConsole::SetCursorPosRel(TPoint const&)
	_ZN8RConsole15SetPaletteEntryEjhhh @ 11 NONAME ; RConsole::SetPaletteEntry(unsigned int, unsigned char, unsigned char, unsigned char)
	_ZN8RConsole15SetWindowPosAbsERK6TPoint @ 12 NONAME ; RConsole::SetWindowPosAbs(TPoint const&)
	_ZN8RConsole16ClearToEndOfLineEv @ 13 NONAME ; RConsole::ClearToEndOfLine()
	_ZN8RConsole16SetTextAttributeE14TTextAttribute @ 14 NONAME ; RConsole::SetTextAttribute(TTextAttribute)
	_ZN8RConsole4InitERK7TDesC16RK5TSize @ 15 NONAME ; RConsole::Init(TDesC16 const&, TSize const&)
	_ZN8RConsole4ReadER11TConsoleKey @ 16 NONAME ; RConsole::Read(TConsoleKey&)
	_ZN8RConsole4ReadER11TConsoleKeyR14TRequestStatus @ 17 NONAME ; RConsole::Read(TConsoleKey&, TRequestStatus&)
	_ZN8RConsole5WriteERK7TDesC16 @ 18 NONAME ; RConsole::Write(TDesC16 const&)
	_ZN8RConsole6CreateEv @ 19 NONAME ; RConsole::Create()
	_ZN8RConsole7ControlERK7TDesC16 @ 20 NONAME ; RConsole::Control(TDesC16 const&)
	_ZN8RConsole7DestroyEv @ 21 NONAME ; RConsole::Destroy()
	_ZN8RConsole7SetModeE10TVideoMode @ 22 NONAME ; RConsole::SetMode(TVideoMode)
	_ZN8RConsole7SetSizeERK5TSize @ 23 NONAME ; RConsole::SetSize(TSize const&)
	_ZN8RConsole7VersionEv @ 24 NONAME ; RConsole::Version()
	_ZN8RConsole8SetTitleERK7TDesC16 @ 25 NONAME ; RConsole::SetTitle(TDesC16 const&)
	_ZNK11TConsoleKey4CodeEv @ 26 NONAME ; TConsoleKey::Code() const
	_ZNK11TConsoleKey4TypeEv @ 27 NONAME ; TConsoleKey::Type() const
	_ZNK11TConsoleKey8MousePosEv @ 28 NONAME ; TConsoleKey::MousePos() const
	_ZNK11TConsoleKey9ModifiersEv @ 29 NONAME ; TConsoleKey::Modifiers() const
	_ZNK8RConsole10ScreenSizeER5TSize @ 30 NONAME ; RConsole::ScreenSize(TSize&) const
	_ZNK8RConsole4SizeER5TSize @ 31 NONAME ; RConsole::Size(TSize&) const
	_ZNK8RConsole9CursorPosER6TPoint @ 32 NONAME ; RConsole::CursorPos(TPoint&) const

